using System;
using System.ComponentModel;
using System.Xml.Serialization;

namespace EQIA.EQIDL
{
    public partial class WindowDrawTemplate : Class
    {
        #region Members

        string myBackground;

        ScrollbarDrawTemplate myVSBTemplate;
        ScrollbarDrawTemplate myHSBTemplate;
        ButtonDrawTemplate myCloseBox;
        ButtonDrawTemplate myQMarkBox;
        ButtonDrawTemplate myMinimizeBox;
        ButtonDrawTemplate myTileBox;
        FrameTemplate myBorder;
        FrameTemplate myTitlebar;

        #endregion

        #region Properties

        /// <summary>Background texture (tiled)</summary>
        [XmlElement("Background", IsNullable = false), Category("Appearance"), Description("Background texture (tiled)")]
        public string Background { get { return myBackground; } set { myBackground = value; } }

        /// <summary>Scrollbar tempalte for vertical scroll bars</summary>
        [XmlElement("VSBTemplate", IsNullable = false), Category("Templates"), Description("Scrollbar template for vertical scroll bars")]
        public ScrollbarDrawTemplate VSBTemplate { get { return myVSBTemplate; } set { myVSBTemplate = value; } }

        /// <summary>Scrollbar template for horizontal scroll bar</summary>
        [XmlElement("HSBTemplate", IsNullable = false), Category("Templates"), Description("Scrollbar template for horizontal scroll bars")]
        public ScrollbarDrawTemplate HSBTemplate { get { return myHSBTemplate; } set { myHSBTemplate = value; } }

        /// <summary>Close button template</summary>
        [XmlElement("CloseBox", IsNullable = false), Category("Templates"), Description("Close button template")]
        public ButtonDrawTemplate CloseBox { get { return myCloseBox; } set { myCloseBox = value; } }

        /// <summary>Question mark template</summary>
        [XmlElement("QMarkBox", IsNullable = false), Category("Templates"), Description("Help button template")]
        public ButtonDrawTemplate QMarkBox { get { return myQMarkBox; } set { myQMarkBox = value; } }

        /// <summary>Minimize button template</summary>
        [XmlElement("MinimizeBox", IsNullable = false), Category("Templates"), Description("Minimize button template")]
        public ButtonDrawTemplate MinimizeBox { get { return myMinimizeBox; } set { myMinimizeBox = value; } }

        /// <summary>Tilebox button template</summary>
        [XmlElement("TileBox", IsNullable = false), Category("Templates"), Description("TileBox button template")]
        public ButtonDrawTemplate TileBox { get { return myTileBox; } set { myTileBox = value; } }

        /// <summary>Border template</summary>
        [XmlElement("Border", IsNullable = false), Category("Templates"), Description("Border template")]
        public FrameTemplate Border { get { return myBorder; } set { myBorder = value; } }

        /// <summary>Titlebar template</summary>
        [XmlElement("Titlebar", IsNullable = false), Category("Templates"), Description("Titlebar template")]
        public FrameTemplate Titlebar { get { return myTitlebar; } set { myTitlebar = value; } }

        #endregion

        #region Creation

        public WindowDrawTemplate()
            : this(null)
        {
        }

        public WindowDrawTemplate(EQInterface eqInterface)
            : base(eqInterface)
        {
        }

        #endregion

        #region Deserialization

        protected override void SetProperties(object obj)
        {
            base.SetProperties(obj);

            WindowDrawTemplate temp_WindowDrawTemplate = obj as WindowDrawTemplate;
            if (temp_WindowDrawTemplate != null)
            {
                Background = temp_WindowDrawTemplate.Background;
                VSBTemplate = temp_WindowDrawTemplate.VSBTemplate;
                HSBTemplate = temp_WindowDrawTemplate.HSBTemplate;
                CloseBox = temp_WindowDrawTemplate.CloseBox;
                QMarkBox = temp_WindowDrawTemplate.QMarkBox;
                MinimizeBox = temp_WindowDrawTemplate.MinimizeBox;
                TileBox = temp_WindowDrawTemplate.TileBox;
                Border = temp_WindowDrawTemplate.Border;
                Titlebar = temp_WindowDrawTemplate.Titlebar;
            }
        }

        #endregion
    }
}
